import * as cdk from 'aws-cdk-lib';
import { IUserPool, UserPoolClient } from 'aws-cdk-lib/aws-cognito';
import { IVpc, ISecurityGroup, ISubnet } from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { Topic } from 'aws-cdk-lib/aws-sns';
/**
 * Cognito configuration for FlowConfig stack
 */
export interface CognitoConfig {
    readonly userPoolId: string;
    /**
     * Full domain name
     */
    readonly domain: string;
    /**
     * If provided, client will auth to SSO. Otherwise will auth to user pool
     */
    readonly ssoProviderName?: string;
}
/**
 * VPC configuration for private deployment using string IDs
 */
export interface VpcConfig {
    /**
     * The VPC ID to deploy resources into
     */
    readonly vpcId: string;
    /**
     * Security group IDs for Lambda functions
     */
    readonly lambdaSecurityGroupIds: string[];
    /**
     * Private subnet IDs for Lambda functions
     */
    readonly privateSubnetIds: string[];
    /**
     * Security group IDs for VPC endpoints
     */
    readonly vpcEndpointSecurityGroupIds: string[];
}
/**
 * Global table configuration for multi-region deployments
 */
export interface GlobalTableConfig {
    /**
     * Whether this is the primary region that creates the global table
     */
    readonly isPrimaryRegion: boolean;
    /**
     * List of all regions that should have replicas
     * Only used by the primary region
     */
    readonly replicaRegions?: string[];
}
/**
 * Internal interface for resolved VPC resources
 */
export interface ResolvedVpcConfig {
    readonly vpc: IVpc;
    readonly lambdaSecurityGroups: ISecurityGroup[];
    readonly privateSubnets: ISubnet[];
    readonly vpcEndpointSecurityGroups: ISecurityGroup[];
}
export interface FlowConfigStackProps extends cdk.StackProps {
    /**
     * Used for resource naming
     */
    readonly prefix: string;
    readonly cognito: CognitoConfig;
    readonly connectInstanceArn: string;
    /**
     * Who to notify for unhandled exceptions
     */
    readonly alertEmails: string[];
    readonly prod?: boolean;
    /**
     * VPC configuration for private deployment.
     * If provided, the application will be configured for VPC-only access.
     * If undefined, uses the current public configuration.
     */
    readonly vpc?: VpcConfig;
    /**
     * Global table configuration for multi-region deployments.
     * If provided, enables global table support.
     * If undefined, creates a single-region table.
     */
    readonly globalTable?: GlobalTableConfig;
}
export declare class FlowConfigStack extends cdk.Stack {
    props: FlowConfigStackProps;
    userPool: IUserPool;
    private api;
    userPoolClient: UserPoolClient;
    alertTopic: Topic;
    table: cdk.aws_dynamodb.ITable;
    /**
     * Resolved VPC configuration if private deployment is enabled
     */
    private readonly _resolvedVpcConfig?;
    /**
     * Get resolved VPC configuration for child constructs
     * @internal
     */
    _getResolvedVpcConfig(): ResolvedVpcConfig | undefined;
    get appUrl(): string;
    constructor(scope: Construct, id: string, props: FlowConfigStackProps);
    createUserPoolClient(): UserPoolClient;
    /**
     * Associated Voicemail as Agent Workspace app
     */
    associate3pApp(): void;
    /**
     * Create DynamoDB table with optional global table support
     */
    private createTable;
    /**
     * Resolve VPC configuration string IDs to CDK objects
     */
    private resolveVpcConfig;
}
